.. _sphinx_ext:

Sphinx extensions
-----------------


To help users document their *Nipype*-based code, the software is shipped
with a set of extensions (currently only one) to customize the appearance
and simplify the generation process.

.. automodule:: nipype.sphinxext.plot_workflow
    :undoc-members:
    :noindex:
